@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2004 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
 
 from __future__ import generators
 import difflib
-import misc
 
 def _null_or_space(s):
     return len(s.strip()) == 0
@@ -78,7 +77,7 @@ class Differ(object):
         # Internally, diffs are stored from text1 -> text0 and text1 -> text2.
         self.num_sequences = len(sequences)
         self.seqlength = [0,0,0]
-        for i,s in misc.enumerate(sequences):
+        for i,s in enumerate(sequences):
             self.seqlength[i] = len(s)
 
         if len(sequences)==0 or len(sequences)==1:
@@ -201,14 +200,18 @@ class Differ(object):
 
     def _merge_blocks(self, using, low_seq, high_seq, last_diff):
         LO, HI = 1,2
-        lowc  = using[low_seq][0][LO]
-        highc = using[high_seq][0][HI]
+        lowc  = using[low_seq][ 0][LO]
+        highc = using[low_seq][-1][HI]
+        if len(using[not low_seq]):
+            lowc  =  min(lowc,  using[not low_seq][ 0][LO])
+            highc =  max(highc, using[not low_seq][-1][HI])
         low = []
         high = []
         for i in (0,1):
             if len(using[i]):
                 d = using[i][0]
                 low.append(  lowc  - d[LO] + d[2+LO] )
+                d = using[i][-1]
                 high.append( highc - d[HI] + d[2+HI] )
             else:
                 d = last_diff
@@ -298,19 +301,20 @@ class Differ(object):
         self.diffs = diffs
         self.num_sequences = len(sequences)
         self.seqlength = [0,0,0]
-        for i,s in misc.enumerate(sequences):
+        for i,s in enumerate(sequences):
             self.seqlength[i] = len(s)
         yield 1
 
 def main():
-    t0 = open("test/lao").readlines()
-    tc = open("test/tzu").readlines()
-    t1 = open("test/tao").readlines()
+    pass
+#    t0 = open("test/lao").readlines()
+#    tc = open("test/tzu").readlines()
+#    t1 = open("test/tao").readlines()
+#
+#    thread0 = IncrementalSequenceMatcher(None, tc, t0).get_difference_opcodes()
+#    thread1 = IncrementalSequenceMatcher(None, tc, t1).get_difference_opcodes()
+#
+#    texts = (t0,tc,t1)
 
-    thread0 = IncrementalSequenceMatcher(None, tc, t0).get_difference_opcodes()
-    thread1 = IncrementalSequenceMatcher(None, tc, t1).get_difference_opcodes()
-
-    texts = (t0,tc,t1)
-
-if __name__=="__main__": 
+if __name__=="__main__":
     main()
