@@ -158,7 +158,9 @@ class EmblemCellRenderer(gtk.GenericCellRenderer):
             r.set_property("pixbuf", self.pixbuf)
             self.size = r.get_size(widget, cell_area)
         return self.size
-gobject.type_register(EmblemCellRenderer)
+
+if gobject.pygtk_version < (2,8,0):
+    gobject.type_register(EmblemCellRenderer)
 
 ################################################################################
 #
@@ -358,7 +360,7 @@ class DirDiff(melddoc.MeldDoc, gnomeglade.Component):
 
     def _search_recursively_iter(self, rootpath):
         self.filter_hide_current.set_sensitive(False)
-        yield _("[%s] Scanning") % self.label_text
+        yield _("[%s] Scanning %s") % (self.label_text, "")
         prefixlen = 1 + len( self.model.value_path( self.model.get_iter(rootpath), 0 ) )
         symlinks_followed = {} # only follow symlinks once
         todo = [ rootpath ]
@@ -517,7 +519,7 @@ class DirDiff(melddoc.MeldDoc, gnomeglade.Component):
                         dstdir = os.path.dirname( dst )
                         if not os.path.exists( dstdir ):
                             os.makedirs( dstdir )
-                        shutil.copy( src, dstdir )
+                        shutil.copy2( src, dstdir )
                         self.file_created( path, dst_pane)
                     elif os.path.isdir(src):
                         if os.path.exists(dst):
@@ -999,4 +1001,5 @@ class DirDiff(melddoc.MeldDoc, gnomeglade.Component):
                 goto_iter(it)
                 return
 
-gobject.type_register(DirDiff)
+if gobject.pygtk_version < (2,8,0):
+    gobject.type_register(DirDiff)
