@@ -334,6 +334,8 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                         self.prefs.use_syntax_highlighting )
         elif key == "regexes":
             self._update_regexes()
+        elif key == "edit_wrap_lines":
+            [t.set_wrap_mode( self.prefs.edit_wrap_lines ) for t in self.textview]
 
     def on_key_press_event(self, object, event):
         x = self.keylookup.get(event.keyval, 0)
@@ -543,13 +545,18 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
             filenames.append( self._get_filename(i) )
         shortnames = misc.shorten_names(*filenames)
         for i in range(self.num_panes):
+            stock = None
             if self.bufferdata[i].modified == 1:
                 shortnames[i] += "*"
-                self.statusimage[i].show()
-                self.statusimage[i].set_from_stock(gtk.STOCK_SAVE, gtk.ICON_SIZE_SMALL_TOOLBAR)
+                if self.bufferdata[i].writable == 1:
+                    stock = gtk.STOCK_SAVE
+                else:
+                    stock = gtk.STOCK_SAVE_AS
             elif self.bufferdata[i].writable == 0:
+                stock = gtk.STOCK_NO
+            if stock:
                 self.statusimage[i].show()
-                self.statusimage[i].set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_SMALL_TOOLBAR)
+                self.statusimage[i].set_from_stock(stock, gtk.ICON_SIZE_SMALL_TOOLBAR)
             else:
                 self.statusimage[i].hide()
         self.label_text = " : ".join(shortnames)
@@ -641,6 +648,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                         t.buf.insert( t.buf.get_end_iter(), nextbit )
                         t.text.append(nextbit)
                     else:
+                        self.set_buffer_writable(t.buf, os.access(t.filename, os.W_OK))
                         self.bufferdata[t.pane].encoding = t.codec[0]
                         if hasattr(t.file, "newlines"):
                             self.bufferdata[t.pane].newlines = t.file.newlines
@@ -703,7 +711,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                             bufs[i].apply_tag(tags[i], s, e)
                         back = (0,0)
                     yield 1
- 
+
     def on_textview_expose_event(self, textview, event):
         if self.num_panes == 1:
             return
@@ -794,7 +802,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                 buttons = {'\n':("UNIX (LF)",0), '\r\n':("DOS (CR-LF)", 1), '\r':("MAC (CR)",2) }
                 newline = misc.run_dialog( _("This file '%s' contains a mixture of line endings.\n\nWhich format would you like to use?") % bufdata.filename,
                     self, gtk.MESSAGE_WARNING, buttonstype=gtk.BUTTONS_CANCEL,
-                    extrabuttons=[ buttons[b] for b in bufdata.newlines ] ) 
+                    extrabuttons=[ buttons[b] for b in bufdata.newlines ] )
                 if newline < 0:
                     return
                 for k,v in buttons.items():
@@ -849,7 +857,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
 
     def set_buffer_writable(self, buf, yesno):
         pane = self.textview.index(buf.textview)
-        self.bufferdata[pane].writing = yesno
+        self.bufferdata[pane].writable = yesno
         self.recompute_label()
 
     def set_buffer_modified(self, buf, yesno):
@@ -943,9 +951,10 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                 others.reverse()
 
             # the line to search for in the 'master' text
-            line  = (adjustment.value + adjustment.page_size * syncpoint)
-            line *= self._get_line_count(master)
-            line /= (adjustment.upper - adjustment.lower) 
+            master_y = adjustment.value + adjustment.page_size * syncpoint
+            it = self.textview[master].get_line_at_y(master_y)[0]
+            line_y, height = self.textview[master].get_line_yrange(it)
+            line = it.get_line() + ((master_y-line_y)/height)
 
             for (i,adj) in others:
                 mbegin,mend, obegin,oend = 0, self._get_line_count(master), 0, self._get_line_count(i)
@@ -965,7 +974,10 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                         obegin = c[3]
                 fraction = (line - mbegin) / ((mend - mbegin) or 1)
                 other_line = (obegin + fraction * (oend - obegin))
-                val = adj.lower + (other_line / self._get_line_count(i) * (adj.upper - adj.lower)) - adj.page_size * syncpoint
+                it = self.textview[i].get_buffer().get_iter_at_line(other_line)
+                val, height = self.textview[i].get_line_yrange(it)
+                val -= (adj.page_size) * syncpoint
+                val += (other_line-int(other_line)) * height
                 val = misc.clamp(val, 0, adj.upper - adj.page_size)
                 adj.set_value( val )
 
@@ -1049,7 +1061,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
 
     def _pixel_to_line(self, pane, pixel ):
         return self.textview[pane].get_line_at_y( pixel )[0].get_line()
-        
+
     def next_diff(self, direction):
         adjs = map( lambda x: x.get_vadjustment(), self.scrolledwindow)
         curline = self._pixel_to_line( 1, int(adjs[1].value + adjs[1].page_size/2) )
@@ -1110,7 +1122,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         #
     def on_linkmap_expose_event(self, area, event):
         window = area.window
-        # not mapped? 
+        # not mapped?
         if not window: return
         if not hasattr(area, "meldgc"):
             self._setup_gcs(area)
@@ -1174,7 +1186,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
             if draw_style > 0:
                 n = (1, 9)[draw_style-1]
                 points0 = []
-                points1 = [] 
+                points1 = []
                 for t in map(lambda x: float(x)/n, range(n+1)):
                     points0.append( (int(    t*wtotal), int((1-f(t))*f0 + f(t)*t0 )) )
                     points1.append( (int((1-t)*wtotal), int(f(t)*f1 + (1-f(t))*t1 )) )
@@ -1265,7 +1277,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         return 0
 
     def on_linkmap_motion_notify_event(self, area, event):
-        return 
+        return
         #dx = event.x - self.linkmap_drag_coord
         #self.linkmap_drag_coord = event.x
         #w,h = self.scrolledwindow0.size_request()
@@ -1316,7 +1328,8 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
     def on_linkmap_drag_begin(self, *args):
         print args
 
-gobject.type_register(FileDiff)
+if gobject.pygtk_version < (2,8,0):
+    gobject.type_register(FileDiff)
 
 ################################################################################
 #
@@ -1335,21 +1348,21 @@ class MeldBufferData(object):
 
 ################################################################################
 #
-# BufferInsertionAction 
+# BufferInsertionAction
 #
 ################################################################################
 class BufferInsertionAction(object):
     """A helper to undo/redo text insertion into a text buffer"""
     def __init__(self, buffer, offset, text):
         self.buffer = buffer
-        self.offset = offset 
+        self.offset = offset
         self.text = text
     def undo(self):
         b = self.buffer
         b.delete( b.get_iter_at_offset( self.offset), b.get_iter_at_offset(self.offset + len(self.text)) )
     def redo(self):
         b = self.buffer
-        b.insert( b.get_iter_at_offset( self.offset), self.text) 
+        b.insert( b.get_iter_at_offset( self.offset), self.text)
 
 ################################################################################
 #
@@ -1360,17 +1373,17 @@ class BufferDeletionAction(object):
     """A helper to undo/redo text deletion from a text buffer"""
     def __init__(self, buffer, offset, text):
         self.buffer = buffer
-        self.offset = offset 
+        self.offset = offset
         self.text = text
     def undo(self):
         b = self.buffer
-        b.insert( b.get_iter_at_offset( self.offset), self.text) 
+        b.insert( b.get_iter_at_offset( self.offset), self.text)
     def redo(self):
         b = self.buffer
         b.delete( b.get_iter_at_offset( self.offset), b.get_iter_at_offset(self.offset + len(self.text)) )
 ################################################################################
 #
-# BufferModifiedAction 
+# BufferModifiedAction
 #
 ################################################################################
 class BufferModifiedAction(object):
