@@ -44,7 +44,7 @@ for sourceview in "gtksourceview sourceview".split():
     except ImportError:
         pass
 
-version = "1.1.1"
+version = "1.1.3"
 
 # magic developer switch, changes some behaviour
 developer = 0
@@ -434,6 +434,7 @@ class MeldPreferences(prefs.Preferences):
         "filters" : prefs.Value(prefs.STRING, "Backups\t1\t#*# .#* ~* *~ *.{orig,bak,swp}\n" + \
                                               "CVS\t1\tCVS\n" + \
                                               "SVN\t1\t.svn\n" + \
+                                              "Monotone\t1\tMT\n" + \
                                               "Binaries\t1\t*.{pyc,a,obj,o,so,la,lib,dll}\n" + \
                                               "Media\t0\t*.{jpg,gif,png,wav,mp3,ogg,xcf,xpm}"),
         "regexes" : prefs.Value(prefs.STRING, "CVS keywords\t0\t\$\\w+(:[^\\n$]+)?\$\n" + \
@@ -829,7 +830,7 @@ def main():
     sys.stdout = Unbuffered(sys.stdout)
     args = sys.argv[1:]
 
-    if len(args) >= 2:
+    if args:
         if "-h" in args or "--help" in args:
             print usage_string
             return
