@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2003 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -46,7 +46,8 @@ class MeldDoc(gobject.GObject):
 
     def save(self):
         pass
-    def save_all(self):
+
+    def save_file(self, pane, saveas=0):
         pass
 
     def stop(self):
@@ -125,4 +126,5 @@ class MeldDoc(gobject.GObject):
         """
         pass
 
-gobject.type_register(MeldDoc)
+if gobject.pygtk_version < (2,8,0):
+    gobject.type_register(MeldDoc)
