@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2004 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 
 from __future__ import generators
 import copy
-import sys
 import os
 import select
 import popen2
@@ -28,7 +27,6 @@ import errno
 import gtk
 import shutil
 import re
-import os
 import signal
 
 whitespace_re = re.compile(r"\s")
@@ -49,8 +47,8 @@ def run_dialog( text, parent=None, messagetype=gtk.MESSAGE_WARNING, buttonstype=
         '<span weight="bold" size="larger">%s</span>' % text)
     if parent:
         d.set_transient_for(parent.widget.get_toplevel())
-    for b,id in extrabuttons:
-        d.add_button(b,id)
+    for b,rid in extrabuttons:
+        d.add_button(b,rid)
     d.vbox.set_spacing(12)
     hbox = d.vbox.get_children()[0]
     hbox.set_spacing(12)
@@ -117,7 +115,7 @@ def shorten_names(*names):
             base = basenames[0].strip()
             return [ r+base for r in roots ]
     # no common path. empty names get changed to "[None]"
-    return map( lambda x: x or _("[None]"), names)
+    return map( lambda x: x or _("[None]"), basenames)
 
 def look(s, o):
     """Return a list of attributes in 'o' which contain the string 's'
@@ -138,8 +136,8 @@ def read_pipe_iter(command, errorstream, yield_interval=0.1, workdir=None):
     """Read the output of a shell command iteratively.
 
     Each time 'callback_interval' seconds pass without reading any data,
-    this function yeilds None.
-    When all the data is read, the entire string is yeilded.
+    this function yields None.
+    When all the data is read, the entire string is yielded.
     If 'workdir' is specified the command is run from that directory.
     """
     class sentinel(object):
@@ -212,14 +210,6 @@ def clamp(val, lower, upper):
     assert lower <= upper
     return min( max(val, lower), upper)
 
-def enumerate(seq):
-    """Emulate enumerate from python2.3.
-    """
-    i = 0
-    for s in seq:
-        yield (i,s)
-        i += 1
-
 def commonprefix(dirs):
     """Given a list of pathnames, returns the longest common leading component.
     """
@@ -237,11 +227,19 @@ def commonprefix(dirs):
     return os.sep.join(prefix)
 
 def escape(s):
-    """Replace special characters '&', '<' and '>' by SGML entities.
+    """Replace special characters by SGML entities.
     """
-    s = s.replace("&", "&amp;")
-    s = s.replace("<", "&lt;")
-    s = s.replace(">", "&gt;")
+    entities = ("&&amp;", "<&lt;", ">&gt;")
+    for e in entities:
+        s = s.replace(e[0], e[1:])
+    return s
+
+def unescape(s):
+    """Inverse of escape.
+    """
+    entities = (">&gt;", "<&lt;", "&&amp;")
+    for e in entities:
+        s = s.replace(e[1:], e[0])
     return s
 
 def copytree(src, dst, symlinks=1):
